/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2009 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                                                          *
*********************************************************************************
* Id: fxmoviemanager.h,   v 3.6                    2008/01/01                   *
*********************************************************************************
* This program is free software; you can redistribute it and/or modify          *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#ifndef FXMOVIEMANAGER_H
#define FXMOVIEMANAGER_H

// #define HAVE_LIBFOX_1_6
// #define HAVE_LIBFOX_1_7
#include <signal.h>

//! the main program class. Here, is to be defined if using either fox-1.6 or
//! fox-1.7 development libraries.

class PropertiesDialog_lp;
class PropertiesDialog_rp;
class MimeTypeDialog;

class FXMovieManager : public FXMainWindow {
	FXDECLARE(FXMovieManager)

private:
	FXMovieManager() {}

protected:
	// declare dialog classes
	PropertiesDialog_lp *properties_lp;
	PropertiesDialog_rp *properties_rp;
	MimeTypeDialog 	*mimetype;
	// logo
	FXIcon		*logoicon;
	// themes buttons
	FXIcon		*audioicon;
	FXIcon		*createicon; 
	FXIcon		*decreaseicon; 
	FXIcon		*deleteicon; 
	FXIcon		*deletehiddenicon; 
	FXIcon		*downicon;
	FXIcon		*dropicon; 
	FXIcon		*hiddenicon;
	FXIcon		*hideicon; 
	FXIcon		*increaseicon; 
	FXIcon		*loopicon;
	FXIcon		*openicon; 
	FXIcon		*pauseicon;
	FXIcon		*playicon;
	FXIcon		*quiticon;
	FXIcon     	*recreateicon; 
	FXIcon     	*showicon; 
	FXIcon     	*stopicon;
	FXIcon		*upicon;
	FXIcon     	*videoouticon;
	FXIcon     	*videosizeicon;
	FXIcon     	*videozoomicon;
	FXIcon     	*videoicon;
	FXIcon		*detlisticon;
	FXIcon     	*icnlisticon;
	FXIcon		*imgpreview1icon;
	FXIcon     	*imgpreview2icon;
	// menus buttons
	FXIcon	   	*m_bugicon;
	FXIcon	   	*m_upicon;
	FXIcon	   	*m_downicon;
	FXIcon	   	*m_appendicon;
	FXIcon	   	*m_accepticon;
	FXIcon	   	*m_cancelicon;
	FXIcon	   	*m_propicon;
	FXIcon	   	*m_copyicon;
	FXIcon	   	*m_moveicon;
	FXIcon	   	*m_renameicon;
	FXIcon	   	*m_archiveicon;
	FXIcon	   	*m_mapicon;
	FXIcon	   	*m_unmapicon;
	FXIcon	   	*m_deleteicon;
	FXIcon	   	*m_refreshicon;
	FXIcon	   	*m_renamediricon;
	FXIcon	   	*m_showhiddenicon;

  	FXTabBook*      leftpanel_tabbook;
  	FXTabItem*      tab_dirlist_lp;
  	FXTabItem*      tab_filelist_lp;

  	FXTabBook*      rightpanel_tabbook;
  	FXTabItem*      tab_dirlist_rp;
  	FXTabItem*      tab_filelist_rp;

	// Menus
	FXMenuBar 	*menubar;           
	FXMenuPane 	*popupmenu;         
	FXMenuPane 	*videosizemenu;
	FXMenuPane 	*videooutmenu;
	FXMenuPane 	*archivemenu;
	FXMenuPane 	*compressmenu;

	FXLabel 	*playlistlabel;

	FXSplitter 	*splitter1;
	FXSplitter 	*splitter2;

	FXHorizontalFrame *listframe;   // the list frame	
	FXTable		*table;	
	FXVerticalFrame *listbuttonframe;

	FXHorizontalFrame *filebuttonframe_lp;
	FXVerticalFrame *fileframe_lp;
	FXHorizontalFrame *dirframe_tab_lp;
	FXHorizontalFrame *fileframe_tab_lp;
	FXVerticalFrame *vbuttonframe_lp;

	FXHorizontalFrame *filebuttonframe_rp;
	FXVerticalFrame *fileframe_rp;
	FXHorizontalFrame *dirframe_tab_rp;
	FXHorizontalFrame *fileframe_tab_rp;
	FXVerticalFrame *vbuttonframe_rp;

	FXHorizontalFrame *sizeframe;
	FXHorizontalFrame *switchframe;
	FXHorizontalFrame *progressframe;

	FXStatusBar 	*statusbar;

	FXSlider 	*speedslider;
	FXSlider 	*volumeslider;

	FXRealSpinner 	*seekspinner;

	FXDirList  	*dirlist_lp;
	FXDirList  	*dirlist_rp;
	FXFileList 	*filelist_lp;
	FXFileList 	*filelist_rp;

	FXFileDict 	*associations;	// File associations

	FXTextField 	*seekposition1;
	FXTextField 	*seekposition2;
	FXTextField 	*seekposition3;
	FXTextField 	*seekposition4;
	FXTextField 	*endposition1;
	FXTextField 	*endposition2;
	FXTextField 	*endposition3;
	FXTextField 	*endposition4;

	FXTextField 	*clock;

	FXProgressBar 	*progressbar;
	
	FXButton 	*quitbutton;
	FXButton 	*openbutton;
	FXButton 	*playbutton;
	FXButton 	*pausebutton;
	FXButton 	*stopbutton;

	FXToggleButton 	*dropbutton;
	FXToggleButton 	*audiobutton;
	FXToggleButton 	*loopbutton;
	FXToggleButton 	*zoombutton;
	FXToggleButton 	*hidebutton;
	FXToggleButton 	*selectbutton;
	FXToggleButton 	*widebutton;
	FXMenuButton 	*videosizebutton;
	FXMenuButton 	*videooutbutton;

	FXFont          *bodyfont;

protected:

  	FXColor 	theme_fxmmbase;
  	FXColor 	theme_fxmmborder;
  	FXColor 	theme_fxmmfore;
  	FXColor 	theme_fxmmselfore;
  	FXColor 	theme_fxmmmenufore;
  	FXColor 	theme_fxmmtipfore;
  	FXColor 	theme_fxmmback;
  	FXColor 	theme_fxmmselback;
  	FXColor 	theme_fxmmmenuback;
  	FXColor 	theme_fxmmtipback;
  	FXColor 	theme_fxmmhilite;
  	FXColor 	theme_fxmmshadow;

	FXString 	theme;
	FXString 	currentdir_lp; 
	FXString 	currentdir_rp; 
	FXString 	filename;
	FXString 	language;
	FXString 	terminal;
  	FXString 	fontspec;

	FXString 	s_play;
	FXString 	s_command;
	FXString 	s_video;
	FXString 	s_size;
	FXString 	s_full;
	FXString 	s_loop;
	FXString 	s_audio;
	FXString 	s_frame;
	FXString 	s_list;
	FXString 	s_listshow;

	FXString 	currentInfo;
	FXString 	currentFifo;
	FXString 	removeTempFifo;
	FXString 	createTempFifo;

	FXString 	grepvideo;
	FXString 	grepaudio;

	FXString 	quitbuttontext;
	FXString 	openbuttontext;
	FXString 	stopbuttontext;
	FXString 	pausebuttontext;
	FXString 	playbuttontext;
	FXString 	speedbuttontext;
	FXString 	audiobuttontext1;
	FXString 	audiobuttontext2;
	FXString 	dropbuttontext1;
	FXString 	dropbuttontext2;
	FXString 	loopbuttontext1;
	FXString 	loopbuttontext2;
	FXString 	zoombuttontext1;
	FXString 	zoombuttontext2;
	FXString 	hidebuttontext1;
	FXString 	hidebuttontext2;
	FXString 	outputbuttontext;
	FXString 	sizebuttontext;
	FXString 	videobuttontext;
	FXString 	confbuttontext;
	FXString 	upbuttontext;
	FXString 	downbuttontext;
	FXString 	slistbuttontext;
	FXString 	olistbuttontext;
  	FXString 	allbuttontext1;
	FXString 	allbuttontext2;
	FXString 	createbuttontext;
	FXString 	recreatebuttontext;
  	FXString 	widebuttontext1;
	FXString 	widebuttontext2;
  	FXString 	imgbuttontext1;
	FXString 	imgbuttontext2;
	FXString 	deletebuttontext;
	FXString 	clearbuttontext;
	FXString 	increasebuttontext;
	FXString 	decreasebuttontext;
	FXString 	icnlisttext;
	FXString 	detlisttext;

	FXString	map_cmd;
	FXString 	map_label;

        FXString 	dlg_cmd;
	FXString 	dlg_label;
	FXString 	dlg_ext;
	FXint		dlg_form;

	FXint 		i_video;
	FXint 		i_size;
	FXint 		imgw;
	FXint 		imgh;
	FXint 		numtableitems;
	FXint		firstcolwidth;
	FXint		fxmmwheellines;

	FXbool 		listshow;
	FXbool 		isrunning;
	FXbool		widescreen;
	FXbool		leftpanel;

  	// ffmpegthumbnailer options
  	FXint     thumbnailSize;
  	FXint     imageQuality;
  	FXbool    filmStripOverlay;
  	FXbool    workaroundIssues;
  	FXbool    maintainAspectRatio;
  	FXbool    smartFrameSelection;

	FXbool	  autoThumbnailShow;
	FXbool	  autoThumbnailCreate;

protected:
	FXint getTableNums() const;
	FXString returnPlaylist();

	FXbool savePlaylistTable(const FXString& filename);
	FXbool loadPlaylistTable(const FXString& filename);
	FXbool previewListMovie(const FXString& filename, FXint i);
	FXbool previewMovie(FXFileList* panel, const FXString& filename, FXint i, FXint w, FXint h);
	FXbool createImageMovie(const FXString& filetoplay, const FXString& rootname);
	FXbool createInfoMovie(const FXString& filename);
	FXbool freeImageMemory(FXFileList* panel, FXint i);
	FXbool executeCompressCommand(FXFileList* panel, const FXString& dlg_cmd, const FXString& dlg_ext, const FXString& dlg_label, FXint dlg_form);
	FXbool executeMapping(FXFileList* panel, const FXString& map_cmd, const FXString& map_label);
	FXbool loadfile(const FXString& filename);
	FXbool readConfig();
	FXbool themeSelection();
	FXbool languageSelection();

	void showFilelistThumbnails_lp();
	void showFilelistThumbnails_rp();
	void showThumbnails(FXFileList* panel);
	void cmdFilePreview(FXFileList* panel);
	void cmdForceFilePreview(FXFileList* panel);
	void cmdIncFilePreview(FXFileList* panel);
	void cmdDecFilePreview(FXFileList* panel);
	void cmdClearPreview(FXFileList* panel);

	void getFilelistSelection_lp();
	void getFilelistSelection_rp();
	void appendFiledialogSelection();
	void insertFiledialogSelection();
	void resetTable();
	void selectAll();

	void languageEN();
	void languageIT();
	void languageFR();
	void languageDE();
	void languageES();
	void languageRU();
	void themeDG();
	void themeSF();
	void themeCM();
	void quitAppFxmm();

	void cmdFileDelete(FXFileList* panel);
	void cmdFileSymlink(FXFileList* panel, FXFileList* out_panel);
	void cmdFileCopy(FXFileList* panel, FXFileList* out_panel);
	void cmdFileRename(FXFileList* panel, FXFileList* out_panel);

	void cmdFilePlay(FXFileList* panel);
	void cmdFilePause();
	void cmdFileStop();

	void cmdOpen(FXFileList* filepanel, FXDirList* dirpanel);
	void cmdOpenWith(FXFileList* filepanel);
	void cmdExtractArchive(FXFileList* panel);
	int cmdScanVirus(FXFileList* panel);
	void scanFileName(int ret, const char *virname, struct cl_engine *engine, FXString& filetoscan, FXint i);

	FXint getNumFilenames(FXFileList* panel) const;
	FXString* getFilenames(FXFileList* panel) const;
	FXString getDirectory(FXFileList* panel) const;
	void deselectMainDir(FXFileList* panel);

	void cmdProperties(FXFileList* filepanel, FXDialogBox* properties);

public:
	FXMovieManager(FXApp *);
	virtual ~FXMovieManager();
	virtual void create();

	enum{
    	ID_CLOCKTIME = FXMainWindow::ID_LAST,
	ID_FILE,
	ID_AUDIO,
	ID_DROP,
	ID_FULL,
	ID_LOOP,
	ID_PLAY,
	ID_PAUSE,
	ID_STOP,
	ID_QUIT,
	ID_SAVELIST,
	ID_OPENLIST,
	ID_LIST,
	ID_TABLE,
	ID_MOVEUP,
	ID_MOVEDOWN,
	ID_APPEND,
	ID_INSERT,
	ID_DELETE,
	ID_SELECTALL,
	ID_CLEAR,
	ID_PUTBACK,
	ID_PANEL,
	ID_DIRECTORYLIST_LP,
    	ID_UPDIRECTORY_LP,
	ID_DIRDELETE_LP,
	ID_NEWDIR_LP,
	ID_DIRRENAME_LP,
	ID_MAPHOST_LP,
	ID_UNMAPHOST_LP,
	ID_DIRECTORYLIST_RP,
    	ID_UPDIRECTORY_RP,
	ID_DIRDELETE_RP,
	ID_NEWDIR_RP,
	ID_DIRRENAME_RP,
	ID_MAPHOST_RP,
	ID_UNMAPHOST_RP,
	ID_FILELIST_LP,
	ID_FILELIST_RP,
	ID_FILEDELETE_LP,
	ID_FILEDELETE_RP,
	ID_FILEMOVE_LP,
	ID_FILEMOVE_RP,
	ID_FILECOPY_LP,
	ID_FILECOPY_RP,
	ID_FILESYMLINK_LP,
	ID_FILESYMLINK_RP,
	ID_FILERENAME_LP,
	ID_FILERENAME_RP,
    	ID_COMPRESS_TAR_LP,
    	ID_COMPRESS_GZ_LP,
    	ID_COMPRESS_BZ_LP,
    	ID_COMPRESS_7Z_LP,
    	ID_COMPRESS_Z_LP,
    	ID_EXTRACT_LP,
    	ID_COMPRESS_TAR_RP,
    	ID_COMPRESS_GZ_RP,
    	ID_COMPRESS_BZ_RP,
    	ID_COMPRESS_7Z_RP,
    	ID_COMPRESS_Z_RP,
    	ID_EXTRACT_RP,
	ID_SCANVIRUS_LP,
	ID_SCANVIRUS_RP,	
	ID_FILEPLAY_LP,
	ID_FILEPLAY_RP,
	ID_FILEPAUSE_LP,
	ID_FILEPAUSE_RP,
	ID_FILESTOP_LP,
	ID_FILESTOP_RP,
	ID_FILEPREVIEW_LP,
	ID_FILEPREVIEW_RP,
	ID_FORCEFILEPREVIEW_LP,
	ID_FORCEFILEPREVIEW_RP,
	ID_INCFILEPREVIEW_LP,
	ID_INCFILEPREVIEW_RP,
	ID_DECFILEPREVIEW_LP,
	ID_DECFILEPREVIEW_RP,
	ID_CLEARPREVIEW_LP,
	ID_CLEARPREVIEW_RP,
	ID_WIDESCREEN,
	ID_TERMINAL_LP,
	ID_TERMINAL_RP,

    	ID_FILE_CREATED_LP,
    	ID_FILE_MODIFIED_LP,
    	ID_FILE_TYPE_LP,
	ID_FILE_MIMETYPE_LP,
	ID_FILE_COMMAND_LP,
    	ID_FILE_LOCATION_LP,
    	ID_FILE_SIZE_LP,
    	ID_FILE_DESC_LP,

    	ID_FILE_CREATED_RP,
    	ID_FILE_MODIFIED_RP,
    	ID_FILE_TYPE_RP,
	ID_FILE_MIMETYPE_RP,
	ID_FILE_COMMAND_RP,
    	ID_FILE_LOCATION_RP,
    	ID_FILE_SIZE_RP,
    	ID_FILE_DESC_RP,

	ID_PROPERTIES_LP,
	ID_PROPERTIES_RP,
	ID_VIDEO_ASPECT,
	ID_AUDIO_FORMAT,

	ID_MIMETYPE,

	ID_OPEN_LP,
	ID_OPEN_RP,
    	ID_OPENWITH_LP,
    	ID_OPENWITH_RP,

    	ID_READOWNER_LP,
    	ID_WRITEOWNER_LP,
    	ID_EXECUTEOWNER_LP,
    	ID_READGROUP_LP,
    	ID_WRITEGROUP_LP,
    	ID_EXECUTEGROUP_LP,
    	ID_READOTHER_LP,
    	ID_WRITEOTHER_LP,
    	ID_EXECUTEOTHER_LP,
    	ID_SETUID_LP,
    	ID_SETGID_LP,
    	ID_STICKY_LP,

    	ID_READOWNER_RP,
    	ID_WRITEOWNER_RP,
    	ID_EXECUTEOWNER_RP,
    	ID_READGROUP_RP,
    	ID_WRITEGROUP_RP,
    	ID_EXECUTEGROUP_RP,
    	ID_READOTHER_RP,
    	ID_WRITEOTHER_RP,
    	ID_EXECUTEOTHER_RP,
    	ID_SETUID_RP,
    	ID_SETGID_RP,
    	ID_STICKY_RP,

    	ID_OWNER_LP,
    	ID_OWNER_RP,
    	ID_GROUP_LP,
    	ID_GROUP_RP,

	ID_SIZE_0,
	ID_SIZE_1,
	ID_SIZE_2,
	ID_SIZE_3,
	ID_SIZE_4,
	ID_SIZE_5,
	ID_SIZE_6,
	ID_SIZE_7,
	ID_SIZE_8,
	ID_SIZE_9,
	ID_VIDEO_1,
	ID_VIDEO_2,
	ID_VIDEO_3,
	ID_VIDEO_4,
	ID_VIDEO_5,
	ID_VIDEO_6,
	ID_VIDEO_7,
	ID_VIDEO_8,
	ID_VIDEO_9,
	ID_LAST,
	};

public:
	// clock
  	long onClock(FXObject*,FXSelector,void*);
	// player button commands
	long onCmdQuit(FXObject *,FXSelector,void *);
	long onCmdFile(FXObject *,FXSelector,void *);
	long onCmdAudio(FXObject *,FXSelector,void *);
	long onCmdPlay(FXObject *,FXSelector,void *);
	long onCmdPause(FXObject *,FXSelector,void *);
	long onCmdStop(FXObject *,FXSelector,void *);
	long onCmdDrop(FXObject *,FXSelector,void *);
	long onCmdFull(FXObject *,FXSelector,void *);
	long onCmdLoop(FXObject *,FXSelector,void *);
	long onCmdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr);
	long onUpdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr);
	long onCmdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr);
	long onUpdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr);
	// table
	long onCmdAppend(FXObject*,FXSelector,void*);
	long onCmdInsert(FXObject*,FXSelector,void*);
	long onCmdDelete(FXObject*,FXSelector,void*);
	long onCmdMoveUp(FXObject*,FXSelector,void*);
	long onCmdMoveDown(FXObject*,FXSelector,void*);
	long onCmdSelectAll(FXObject*,FXSelector,void*);
	long onCmdClear(FXObject*,FXSelector,void*);
	long onListRightMouse(FXObject*,FXSelector,void* ptr);
	long onCmdPutBack(FXObject*,FXSelector,void*);
  	long onUpdSelectedTable(FXObject*,FXSelector,void*);
	long onCmdSavePlaylist(FXObject*,FXSelector,void*);
	long onCmdOpenPlaylist(FXObject*,FXSelector,void*);

	// switcher
  	long onCmdPanel(FXObject*,FXSelector,void*);
	// left directory list
  	long onCmdDirectory_lp(FXObject*,FXSelector,void*);
  	long onCmdUpDirectory_lp(FXObject*,FXSelector,void*);
  	long onCmdNewDir_lp(FXObject*,FXSelector,void*);
	long onCmdDirRename_lp(FXObject*,FXSelector,void*);
  	long onUpdNewDir_lp(FXObject*,FXSelector,void*);
  	long onCmdDirDelete_lp(FXObject*,FXSelector,void*);
	long onDirListPopup_lp(FXObject*,FXSelector,void*);
  	long onCmdMapHost_lp(FXObject*,FXSelector,void*);
  	long onCmdUnmapHost_lp(FXObject*,FXSelector,void*);
	// right directory list
  	long onCmdDirectory_rp(FXObject*,FXSelector,void*);
  	long onCmdUpDirectory_rp(FXObject*,FXSelector,void*);
  	long onCmdNewDir_rp(FXObject*,FXSelector,void*);
	long onCmdDirRename_rp(FXObject*,FXSelector,void*);
  	long onUpdNewDir_rp(FXObject*,FXSelector,void*);
  	long onCmdDirDelete_rp(FXObject*,FXSelector,void*);
	long onDirListPopup_rp(FXObject*,FXSelector,void*);
  	long onCmdMapHost_rp(FXObject*,FXSelector,void*);
  	long onCmdUnmapHost_rp(FXObject*,FXSelector,void*);

	// left file list
	long onFileListPopup_lp(FXObject*,FXSelector,void*);
	long onCmdFileListDC_lp(FXObject*,FXSelector,void*);
	long onCmdFileCopy_lp(FXObject*,FXSelector,void*);
	long onCmdFileSymlink_lp(FXObject*,FXSelector,void*);
	long onCmdFileMove_lp(FXObject*,FXSelector,void*);
	long onCmdFileRename_lp(FXObject*,FXSelector,void*);
	long onCmdFileDelete_lp(FXObject*,FXSelector,void*);
  	long onUpdSelectedFile_lp(FXObject*,FXSelector,void*);
	long onCmdFilePlay_lp(FXObject*,FXSelector,void*);
	long onCmdFilePause_lp(FXObject*,FXSelector,void*);
	long onCmdFileStop_lp(FXObject *,FXSelector,void *);
	// right file list
	long onFileListPopup_rp(FXObject*,FXSelector,void*);
	long onCmdFileListDC_rp(FXObject*,FXSelector,void*);
	long onCmdFileCopy_rp(FXObject*,FXSelector,void*);
	long onCmdFileMove_rp(FXObject*,FXSelector,void*);
	long onCmdFileRename_rp(FXObject*,FXSelector,void*);
	long onCmdFileSymlink_rp(FXObject*,FXSelector,void*);
	long onCmdFileDelete_rp(FXObject*,FXSelector,void*);
  	long onUpdSelectedFile_rp(FXObject*,FXSelector,void*);
	long onCmdFilePlay_rp(FXObject*,FXSelector,void*);
	long onCmdFilePause_rp(FXObject*,FXSelector,void*);
	long onCmdFileStop_rp(FXObject *,FXSelector,void *);

	// movie preview
	long onCmdFilePreview_lp(FXObject*,FXSelector,void*);
	long onCmdFilePreview_rp(FXObject*,FXSelector,void*);
	long onCmdForceFilePreview_lp(FXObject*,FXSelector,void*);
	long onCmdForceFilePreview_rp(FXObject*,FXSelector,void*);
	long onCmdIncFilePreview_lp(FXObject*,FXSelector,void*);
	long onCmdIncFilePreview_rp(FXObject*,FXSelector,void*);
	long onCmdDecFilePreview_lp(FXObject*,FXSelector,void*);
	long onCmdDecFilePreview_rp(FXObject*,FXSelector,void*);
	long onCmdClearPreview_lp(FXObject*,FXSelector,void*);
	long onCmdClearPreview_rp(FXObject*,FXSelector,void*);

	long onCmdWideScreen(FXObject*,FXSelector,void*);

	long onCmdTerminal_lp(FXObject*,FXSelector,void*);
	long onCmdTerminal_rp(FXObject*,FXSelector,void*);

  	long onCmdExtract_lp(FXObject*,FXSelector,void*);
  	long onCmdCompressTar_lp(FXObject*,FXSelector,void*);
  	long onCmdCompressGz_lp(FXObject*,FXSelector,void*);
  	long onCmdCompressBz_lp(FXObject*,FXSelector,void*);
  	long onCmdCompress7z_lp(FXObject*,FXSelector,void*);
  	long onCmdCompressZ_lp(FXObject*,FXSelector,void*);

  	long onCmdExtract_rp(FXObject*,FXSelector,void*);
  	long onCmdCompressTar_rp(FXObject*,FXSelector,void*);
  	long onCmdCompressGz_rp(FXObject*,FXSelector,void*);
  	long onCmdCompressBz_rp(FXObject*,FXSelector,void*);
  	long onCmdCompress7z_rp(FXObject*,FXSelector,void*);
  	long onCmdCompressZ_rp(FXObject*,FXSelector,void*);

	long onCmdScanVirus_lp(FXObject*,FXSelector,void*);
	long onCmdScanVirus_rp(FXObject*,FXSelector,void*);

	// properties dialog
  	long onCmdProperties_lp(FXObject*,FXSelector,void*);
  	long onCmdProperties_rp(FXObject*,FXSelector,void*);
  	long onUpdMovieAspect(FXObject*,FXSelector,void*);
  	long onUpdAudioFormat(FXObject*,FXSelector,void*);

  	long onUpdCreatedTime_lp(FXObject*,FXSelector,void*);
  	long onUpdModifiedTime_lp(FXObject*,FXSelector,void*);
  	long onUpdFileType_lp(FXObject*,FXSelector,void*);
  	long onUpdFileMimeType_lp(FXObject*,FXSelector,void*);
  	long onUpdFileCommand_lp(FXObject*,FXSelector,void*);	
  	long onUpdFileLocation_lp(FXObject*,FXSelector,void*);
  	long onUpdFileSize_lp(FXObject*,FXSelector,void*);
  	long onUpdFileDesc_lp(FXObject*,FXSelector,void*);

  	long onUpdCreatedTime_rp(FXObject*,FXSelector,void*);
  	long onUpdModifiedTime_rp(FXObject*,FXSelector,void*);
  	long onUpdFileType_rp(FXObject*,FXSelector,void*);
  	long onUpdFileMimeType_rp(FXObject*,FXSelector,void*);
  	long onUpdFileCommand_rp(FXObject*,FXSelector,void*);	
  	long onUpdFileLocation_rp(FXObject*,FXSelector,void*);
  	long onUpdFileSize_rp(FXObject*,FXSelector,void*);
  	long onUpdFileDesc_rp(FXObject*,FXSelector,void*);

  	long onCmdFilemode_lp(FXObject*,FXSelector,void*);
  	long onUpdFilemode_lp(FXObject*,FXSelector,void*);
  	long onCmdFilemode_rp(FXObject*,FXSelector,void*);
  	long onUpdFilemode_rp(FXObject*,FXSelector,void*);
  	long onUpdOwner_lp(FXObject*,FXSelector,void*);
  	long onUpdOwner_rp(FXObject*,FXSelector,void*);
  	long onUpdGroup_lp(FXObject*,FXSelector,void*);
  	long onUpdGroup_rp(FXObject*,FXSelector,void*);

	// mimetype dialog
  	long onCmdMimeType(FXObject*,FXSelector,void*);

  	long onCmdOpen_lp(FXObject*,FXSelector,void*);
  	long onCmdOpen_rp(FXObject*,FXSelector,void*);
  	long onCmdOpenWith_lp(FXObject*,FXSelector,void*);
  	long onCmdOpenWith_rp(FXObject*,FXSelector,void*);
  	long onUpdItemFound_lp(FXObject*,FXSelector,void*);
  	long onUpdItemFound_rp(FXObject*,FXSelector,void*);
};

#endif
